==> 0.2.tar.gz: construction_management/models/cm_project.go <==
package models

import (
	"time"
)

type CmProject struct {
	Id               int       `xorm:"not null pk autoincr comment('自增ID') INT(11)"`
	Code             string    `xorm:"comment('项目编号') VARCHAR(32)"`
	EnterpriseId     int       `xorm:"comment('企业id') INT(11)"`
	UserId           int       `xorm:"comment('管理员id(sso用户)') INT(11)"`
	UserAccount      string    `xorm:"comment('管理员名字(sso用户名)') VARCHAR(32)"`
	CategoryId       string    `xorm:"comment('办事处ID') VARCHAR(64)"`
	Category         string    `xorm:"comment('办事处') VARCHAR(32)"`
	StaffId          string    `xorm:"comment('负责人Id(cld员工)') VARCHAR(64)"`
	StaffName        string    `xorm:"comment('负责人(cld员工)') VARCHAR(32)"`
	StaffQq          string    `xorm:"comment('负责人QQ') VARCHAR(32)"`
	StaffPhone       string    `xorm:"comment('负责人手机') VARCHAR(32)"`
	StaffTelephone   string    `xorm:"comment('负责人座机') VARCHAR(32)"`
	CreateTime       time.Time `xorm:"comment('创建时间') DATETIME"`
	CreateName       string    `xorm:"comment('创建人') VARCHAR(32)"`
	CreateCategory   string    `xorm:"comment('创建办事处') VARCHAR(32)"`
	InsideCategoryid string    `xorm:"comment('项目所在办事处Id') VARCHAR(32)"`
	InsideCategory   string    `xorm:"comment('项目所在办事处') VARCHAR(32)"`
	JlReciprocate    int       `xorm:"comment('计量互通（1开启）') TINYINT(4)"`
	MaxUser          int       `xorm:"comment('最大创建用户数(删除)') TINYINT(4)"`
	Name             string    `xorm:"comment('项目名称') VARCHAR(128)"`
	Creator          int64     `xorm:"comment('创建者') BIGINT(20)"`
	Status           int       `xorm:"comment('项目状态') TINYINT(1)"`
	Remark           string    `xorm:"comment('备注') VARCHAR(128)"`
	BillId           string    `xorm:"comment('工程量清单id列表') VARCHAR(128)"`
	ChapterId        string    `xorm:"comment('项目节清单id列表') VARCHAR(128)"`
	StandardId       int       `xorm:"comment('标准清单id') TINYINT(4)"`
	Valuation        string    `xorm:"comment('清单规范id列表(删除)') VARCHAR(128)"`
	QrcodeJson       string    `xorm:"comment('项目二维码信息') TEXT"`
	DealpayJson      string    `xorm:"TEXT"`
	Custom           int       `xorm:"comment('是否是定制项目') TINYINT(1)"`
	CanApi           int       `xorm:"comment('定制项目接口是否可用') TINYINT(1)"`
	Secret           string    `xorm:"comment('定制项目私钥') VARCHAR(255)"`
	PageShow         string    `xorm:"comment('前台页面或功能展示与隐藏') VARCHAR(3072)"`
	PagePath         string    `xorm:"VARCHAR(11)"`
}

==> 0.03.tar.gz: construction_management/models/cm_project.go <==
package models

import (
	"time"
)

type CmProject struct {
	Id               int       `xorm:"not null pk comment('自增ID') INT(11)"`
	Code             string    `xorm:"comment('项目编号') VARCHAR(32)"`
	EnterpriseId     int       `xorm:"comment('企业id') INT(11)"`
	UserId           int       `xorm:"comment('管理员id(sso用户)') INT(11)"`
	UserAccount      string    `xorm:"comment('管理员名字(sso用户名)') VARCHAR(32)"`
	CategoryId       string    `xorm:"comment('办事处ID') VARCHAR(64)"`
	Category         string    `xorm:"comment('办事处') VARCHAR(32)"`
	StaffId          string    `xorm:"comment('负责人Id(cld员工)') VARCHAR(64)"`
	StaffName        string    `xorm:"comment('负责人(cld员工)') VARCHAR(32)"`
	StaffQq          string    `xorm:"comment('负责人QQ') VARCHAR(32)"`
	StaffPhone       string    `xorm:"comment('负责人手机') VARCHAR(32)"`
	StaffTelephone   string    `xorm:"comment('负责人座机') VARCHAR(32)"`
	CreateTime       time.Time `xorm:"comment('创建时间') DATETIME"`
	CreateName       string    `xorm:"comment('创建人') VARCHAR(32)"`
	CreateCategory   string    `xorm:"comment('创建办事处') VARCHAR(32)"`
	InsideCategoryid string    `xorm:"comment('项目所在办事处Id') VARCHAR(32)"`
	InsideCategory   string    `xorm:"comment('项目所在办事处') VARCHAR(32)"`
	MaxUser          int       `xorm:"comment('最大创建用户数(删除)') TINYINT(4)"`
	Name             string    `xorm:"comment('项目名称') VARCHAR(128)"`
	Creator          int64     `xorm:"comment('创建者') BIGINT(20)"`
	Status           int       `xorm:"comment('项目状态') TINYINT(1)"`
	Remark           string    `xorm:"comment('备注') VARCHAR(128)"`
	BillId           string    `xorm:"comment('工程量清单id列表') VARCHAR(128)"`
	ChapterId        string    `xorm:"comment('项目节清单id列表') VARCHAR(128)"`
	StandardId       int       `xorm:"comment('标准清单id') TINYINT(4)"`
	Valuation        string    `xorm:"comment('清单规范id列表(删除)') VARCHAR(128)"`
	QrcodeJson       string    `xorm:"comment('项目二维码信息') TEXT"`
	DealpayJson      string    `xorm:"TEXT"`
	Custom           int       `xorm:"comment('是否是定制项目') TINYINT(1)"`
	CanApi           int       `xorm:"comment('定制项目接口是否可用') TINYINT(1)"`
	Secret           string    `xorm:"comment('定制项目私钥') VARCHAR(255)"`
	PageShow         string    `xorm:"comment('前台页面或功能展示与隐藏') VARCHAR(3072)"`
	PagePath         string    `xorm:"VARCHAR(11)"`
}
